@@ -174,7 +174,8 @@ namespace Tomboy
 			}
 
 			Logger.Debug ("Renaming note from {0} to {1}", Note.Title, title);
-			Note.Title = title;
+			Note.SetTitle (title, true);
+
 			return true;
 		}
 
@@ -451,7 +452,7 @@ namespace Tomboy
 		void OpenUrl (string url)
 		{
 			if (url != string.Empty) {
-				Logger.Log ("Opening url '{0}'...", url);
+				Logger.Debug ("Opening url '{0}'...", url);
 				Services.NativeApplication.OpenUrl (url, Note.Window.Screen);
 			}
 		}
@@ -678,29 +679,6 @@ namespace Tomboy
 			// Highlight previously unlinked text
 			if (ContainsText (renamed.Title))
 				HighlightNoteInBlock (renamed, Buffer.StartIter, Buffer.EndIter);
-
-			if (!ContainsText (old_title))
-				return;
-
-			string old_title_lower = old_title.ToLower ();
-
-			// Replace existing links with the new title.
-			NoteTag link_tag = Note.TagTable.LinkTag;
-			TextTagEnumerator enumerator = new TextTagEnumerator (Buffer, link_tag);
-			foreach (TextRange range in enumerator) {
-				if (range.Text.ToLower () != old_title_lower)
-					continue;
-
-				Logger.Log ("Replacing '{0}' with '{1}'",
-				            range.Text,
-				            renamed.Title);
-
-				Gtk.TextIter start_iter = range.Start;
-				Gtk.TextIter end_iter = range.End;
-				Buffer.Delete (ref start_iter, ref end_iter);
-				start_iter = range.Start;
-				Buffer.InsertWithTags (ref start_iter, renamed.Title, link_tag);
-			}
 		}
 
 		void DoHighlight (TrieHit hit, Gtk.TextIter start, Gtk.TextIter end)
@@ -742,7 +720,7 @@ namespace Tomboy
 			if (title_start.HasTag (Note.TagTable.UrlTag))
 				return;
 
-			Logger.Log ("Matching Note title '{0}' at {1}-{2}...",
+			Logger.Debug ("Matching Note title '{0}' at {1}-{2}...",
 			            hit.Key,
 			            hit.Start,
 			            hit.End);
@@ -821,7 +799,7 @@ namespace Tomboy
 			Note link = Manager.Find (link_name);
 
 			if (link == null) {
-				Logger.Log ("Creating note '{0}'...", link_name);
+				Logger.Debug ("Creating note '{0}'...", link_name);
 				try {
 					link = Manager.Create (link_name);
 				} catch {
@@ -836,7 +814,7 @@ namespace Tomboy
 		// as the current note's title, it's safe to omit this check and
 		// also works around the bug.
 		if (link != null) {
-				Logger.Log ("Opening note '{0}' on click...", link_name);
+				Logger.Debug ("Opening note '{0}' on click...", link_name);
 				link.Window.Present ();
 				return true;
 			}
@@ -914,7 +892,7 @@ namespace Tomboy
 			                match = match.NextMatch ()) {
 				System.Text.RegularExpressions.Group group = match.Groups [1];
 
-				Logger.Log ("Highlighting wikiword: '{0}' at offset {1}",
+				Logger.Debug ("Highlighting wikiword: '{0}' at offset {1}",
 				            group,
 				            group.Index);
 
